==> celix-2.2.1.tar.gz: celix-2.2.1/libs/framework/include/celix_api.h <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#ifndef CELIX_CELIX_API_H_
#define CELIX_CELIX_API_H_

#include "properties.h"
#include "array_list.h"
#include "celix_constants.h"
#include "bundle.h"
#include "bundle_context.h"
#include "framework.h"

#include "celix_properties.h"
#include "celix_array_list.h"
//#include "celix_constants.h"
#include "celix_utils_api.h"
#include "celix_bundle.h"
#include "celix_bundle_context.h"

#include "celix_framework.h"
#include "celix_framework_factory.h"
#include "celix_launcher.h"

#include "celix_dependency_manager.h"
#include "celix_dm_component.h"
#include "dm_service_dependency.h"

#include "celix_bundle_activator.h"
#include "celix_framework_factory.h"

#ifdef __cplusplus
#include "celix/dm/DependencyManager.h"
#endif


#endif //CELIX_CELIX_API_H_

==> celix-2.4.0.tar.gz: celix-2.4.0/libs/framework/include/celix_api.h <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#ifndef CELIX_CELIX_API_H_
#define CELIX_CELIX_API_H_

#include "properties.h"
#include "array_list.h"

#include "bundle.h"
#include "bundle_context.h"
#include "framework.h"

#include "celix_properties.h"
#include "celix_array_list.h"
#include "celix_constants.h"
#include "celix_utils_api.h"
#include "celix_bundle.h"
#include "celix_bundle_context.h"

#include "celix_framework.h"
#include "celix_framework_factory.h"
#include "celix_launcher.h"
#include "celix_framework_utils.h"

#include "celix_dependency_manager.h"
#include "celix_dm_component.h"
#include "dm_service_dependency.h"

#include "celix_bundle_activator.h"
#include "celix_framework_factory.h"

#ifdef __cplusplus
#include "celix/BundleActivator.h"
#include "celix/BundleContext.h"
#endif

#endif //CELIX_CELIX_API_H_
